@@ -15,9 +15,7 @@
 
 use std::{collections::BTreeMap, time::Instant, vec::Vec};
 
-use fxhash::FxHashMap;
-use once_cell::sync::Lazy;
-use regex::Regex;
+use hashbrown::HashMap;
 
 #[cfg(feature = "battery")]
 use crate::data_harvester::batteries;
@@ -37,6 +35,8 @@ pub struct TimedData {
     pub cpu_data: Vec<Value>,
     pub load_avg_data: [f32; 3],
     pub mem_data: Option<Value>,
+    #[cfg(not(target_os = "windows"))]
+    pub cache_data: Option<Value>,
     pub swap_data: Option<Value>,
     #[cfg(feature = "zfs")]
     pub arc_data: Option<Value>,
@@ -50,7 +50,7 @@ pub struct ProcessData {
     pub process_harvest: BTreeMap<Pid, ProcessHarvest>,
 
     /// A mapping between a process PID to any children process PIDs.
-    pub process_parent_mapping: FxHashMap<Pid, Vec<Pid>>,
+    pub process_parent_mapping: HashMap<Pid, Vec<Pid>>,
 
     /// PIDs corresponding to processes that have no parents.
     pub orphan_pids: Vec<Pid>,
@@ -110,6 +110,8 @@ pub struct DataCollection {
     pub timed_data_vec: Vec<(Instant, TimedData)>,
     pub network_harvest: network::NetworkHarvest,
     pub memory_harvest: memory::MemHarvest,
+    #[cfg(not(target_os = "windows"))]
+    pub cache_harvest: memory::MemHarvest,
     pub swap_harvest: memory::MemHarvest,
     pub cpu_harvest: cpu::CpuHarvest,
     pub load_avg_harvest: cpu::LoadAvgHarvest,
@@ -134,6 +136,8 @@ impl Default for DataCollection {
             timed_data_vec: Vec::default(),
             network_harvest: network::NetworkHarvest::default(),
             memory_harvest: memory::MemHarvest::default(),
+            #[cfg(not(target_os = "windows"))]
+            cache_harvest: memory::MemHarvest::default(),
             swap_harvest: memory::MemHarvest::default(),
             cpu_harvest: cpu::CpuHarvest::default(),
             load_avg_harvest: cpu::LoadAvgHarvest::default(),
@@ -208,23 +212,25 @@ impl DataCollection {
             self.eat_network(network, &mut new_entry);
         }
 
-        // Memory and Swap
+        // Memory, Swap
         if let (Some(memory), Some(swap)) = (harvested_data.memory, harvested_data.swap) {
             self.eat_memory_and_swap(memory, swap, &mut new_entry);
         }
 
+        // Cache memory
+        #[cfg(not(target_os = "windows"))]
+        if let Some(cache) = harvested_data.cache {
+            self.eat_cache(cache, &mut new_entry);
+        }
+
         #[cfg(feature = "zfs")]
-        {
-            if let Some(arc) = harvested_data.arc {
-                self.eat_arc(arc, &mut new_entry);
-            }
+        if let Some(arc) = harvested_data.arc {
+            self.eat_arc(arc, &mut new_entry);
         }
 
         #[cfg(feature = "gpu")]
-        {
-            if let Some(gpu) = harvested_data.gpu {
-                self.eat_gpu(gpu, &mut new_entry);
-            }
+        if let Some(gpu) = harvested_data.gpu {
+            self.eat_gpu(gpu, &mut new_entry);
         }
 
         // CPU
@@ -281,6 +287,15 @@ impl DataCollection {
         self.swap_harvest = swap;
     }
 
+    #[cfg(not(target_os = "windows"))]
+    fn eat_cache(&mut self, cache: memory::MemHarvest, new_entry: &mut TimedData) {
+        // Cache and buffer memory
+        new_entry.cache_data = cache.use_percent;
+
+        // In addition copy over latest data for easy reference
+        self.cache_harvest = cache;
+    }
+
     fn eat_network(&mut self, network: network::NetworkHarvest, new_entry: &mut TimedData) {
         // RX
         if network.rx > 0 {
@@ -321,23 +336,43 @@ impl DataCollection {
         &mut self, disks: Vec<disks::DiskHarvest>, io: disks::IoHarvest, harvested_time: Instant,
     ) {
         // TODO: [PO] To implement
-
         let time_since_last_harvest = harvested_time
             .duration_since(self.current_instant)
             .as_secs_f64();
 
         for (itx, device) in disks.iter().enumerate() {
-            if let Some(trim) = device.name.split('/').last() {
-                let io_device = if cfg!(target_os = "macos") {
-                    // Must trim one level further for macOS!
-                    static DISK_REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r"disk\d+").unwrap());
-                    if let Some(disk_trim) = DISK_REGEX.find(trim) {
-                        io.get(disk_trim.as_str())
+            let checked_name = {
+                cfg_if::cfg_if! {
+                    if #[cfg(target_os = "windows")] {
+                        match &device.volume_name {
+                            Some(volume_name) => Some(volume_name.as_str()),
+                            None => device.name.split('/').last(),
+                        }
                     } else {
-                        None
+                        device.name.split('/').last()
+                    }
+                }
+            };
+
+            if let Some(checked_name) = checked_name {
+                let io_device = {
+                    cfg_if::cfg_if! {
+                        if #[cfg(target_os = "macos")] {
+                            use once_cell::sync::Lazy;
+                            use regex::Regex;
+
+                            // Must trim one level further for macOS!
+                            static DISK_REGEX: Lazy<Regex> =
+                                Lazy::new(|| Regex::new(r"disk\d+").unwrap());
+                            if let Some(new_name) = DISK_REGEX.find(checked_name) {
+                                io.get(new_name.as_str())
+                            } else {
+                                None
+                            }
+                        } else {
+                            io.get(checked_name)
+                        }
                     }
-                } else {
-                    io.get(trim)
                 };
 
                 if let Some(io_device) = io_device {
@@ -417,7 +452,7 @@ impl DataCollection {
     #[cfg(feature = "gpu")]
     fn eat_gpu(&mut self, gpu: Vec<(String, memory::MemHarvest)>, new_entry: &mut TimedData) {
         // Note this only pre-calculates the data points - the names will be
-        // within the local copy of gpu_harvest.  Since it's all sequential
+        // within the local copy of gpu_harvest. Since it's all sequential
         // it probably doesn't matter anyways.
         gpu.iter().for_each(|data| {
             new_entry.gpu_data.push(data.1.use_percent);
