@@ -882,8 +882,9 @@ pub struct BottomWidget {
     pub bottom_right_corner: Option<(u16, u16)>,
 }
 
-#[derive(Debug, Clone, Eq, PartialEq, Hash)]
+#[derive(Debug, Clone, Eq, PartialEq, Hash, Default)]
 pub enum BottomWidgetType {
+    #[default]
     Empty,
     Cpu,
     CpuLegend,
@@ -927,12 +928,6 @@ impl BottomWidgetType {
     }
 }
 
-impl Default for BottomWidgetType {
-    fn default() -> Self {
-        BottomWidgetType::Empty
-    }
-}
-
 impl std::str::FromStr for BottomWidgetType {
     type Err = BottomError;
 
@@ -998,10 +993,11 @@ Supported widget names:
     }
 }
 
-#[derive(Clone, Default, Debug)]
+#[derive(Clone, Default, Debug, Copy)]
 pub struct UsedWidgets {
     pub use_cpu: bool,
     pub use_mem: bool,
+    pub use_cache: bool,
     pub use_gpu: bool,
     pub use_net: bool,
     pub use_proc: bool,
